﻿using System;
using System.Runtime.InteropServices;

using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;

using System.Configuration;
using System.Data;
using System.Web.UI.WebControls;
using Microsoft.SharePoint.Utilities;
using System.Web.UI;
using System.Text;


namespace Belgradum
{
    // TODO: Replace, as needed, "TextField" with some other class derived from Microsoft.SharePoint.WebControls.BaseFieldControl.
    [CLSCompliant(false)]
    [Guid("7e0e1a5f-27cd-474b-8f73-912260f941e9")]
    public class ParentChildrenFieldControl : TextField
    {
        int NumOfChildren = 0;
        LiteralControl literalCtrl;
        SPList childList = null;
        Guid listID = SPContext.Current.List.ID; //.ToString();
        HyperLink linkAddNew = new HyperLink();

        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            if (this.ControlMode == SPControlMode.Display ||
                this.ControlMode == SPControlMode.Edit ||
                this.ControlMode == SPControlMode.New)
            {
                literalCtrl = new LiteralControl();
                base.Controls.Add(literalCtrl);
                base.Controls.Add(linkAddNew);
            }
        }


        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            string childListname = this.Field.GetCustomProperty("ChildListName").ToString();
            try
            {
                try
                {
                    childList = SPContext.Current.Web.Lists[childListname];
                }
                catch
                {
                    throw new ConfigurationErrorsException(@"Child List " + childListname + " doesn't exist at the site.");
                }

                StringBuilder sb = new StringBuilder();
                try
                {
                    SPQuery query = new SPQuery(childList.DefaultView);
                    query.Query = string.Format(@"
                        <Where>
                            <Eq>
                                <FieldRef Name='{0}' LookupId='true' />
                                <Value Type='Integer'>{1}</Value>
                            </Eq>
                        </Where>", LookupField.InternalName, this.Item.ID.ToString()); 
                    sb.Append(childList.RenderAsHtml(query));
                }
                catch (Exception ex)
                {
                    sb.Append("<p>There was an error loading the list information:<br />");
                    sb.Append(ex.Message);
                    sb.Append("</p>");
                }
                literalCtrl.Text = sb.ToString();
                
                // Add new
                linkAddNew.Text = "Add New";
                string navigateUrl = string.Format("/NewForm.aspx?{0}={1}&Source={2}", SPEncode.UrlEncode(LookupField.Title), SPContext.Current.ListItem.ID.ToString(), SPEncode.UrlEncode(this.Page.Request.Url.ToString()));
                linkAddNew.NavigateUrl = childList.RootFolder.ServerRelativeUrl + navigateUrl; 
            }
            catch (Exception ex)
            {
                literalCtrl.Text = ex.Message;
            }
        }

        SPField _LookupField = null;
        SPField LookupField
        {
            get
            {
                if (_LookupField == null) {
                    foreach (SPField field in childList.Fields) {
                        if (field is SPFieldLookup && listID == new Guid(((SPFieldLookup)field).LookupList)) {
                            _LookupField = field;
                            break;
                        }
                    }
                }
                return _LookupField;
            }
        }

        protected override void Render(HtmlTextWriter output)
        {
            literalCtrl.RenderControl(output);
            // Add New link
            if (this.ControlMode == SPControlMode.Display ||
                this.ControlMode == SPControlMode.Edit)
                linkAddNew.RenderControl(output);
        }

        public override void UpdateFieldValueInItem()
        {
            this.EnsureChildControls();

            try
            {
                this.Value = NumOfChildren;
                this.ItemFieldValue = this.Value;
            }
            catch (Exception)
            {
                ;
            }
        }

        #region NewForm JavaScript code
        /*
<script type="text/javascript">
var qs = location.search.substring(1, location.search.length);  
var nameVal = qs.split("&")[0].split("=");  
SetLookupFieldValue(unescape(nameVal[0]), nameVal[1]);
	
function SetLookupFieldValue(fieldName, val) {
    var theSelect = getTagFromIdentifierAndTitle("select", "Lookup", fieldName);
    if (theSelect != null) {
	    theSelect.value = val;
        return;
    }
    // if theSelect is null, 
    // it means that the target list has more than 20 items, 
    // and the Lookup is being rendered with an input element
    var theInput = getTagFromIdentifierAndTitle("input", "", fieldName);
	theInput.value = val;
}

function getTagFromIdentifierAndTitle(tagName, identifier, title) {
    var len = identifier.length;
    var tags = document.getElementsByTagName(tagName);
    for (var i = 0; i < tags.length; i++) {
        var tempString = tags[i].id;
        if (tags[i].title == title && (identifier == "" || tempString.indexOf(identifier) == tempString.length - len)) {
            return tags[i];
        }
    }
    return null;
}	
</script>
         */
#endregion

    }
}
